@@ -16,27 +16,23 @@ class DenonReceiver(AVReceiver):
         self,
         host,
         *,
-        telnet: bool = True,
-        http: bool = True,
-        http_api=None,
-        upnp: bool = True,
-        timeout: float = denon_const.DEFAULT_TIMEOUT,
-        heart_beat: Optional[float] = denon_const.DEFAULT_HEART_BEAT,
         dispatcher: Dispatcher = Dispatcher(),
-        main_zone: DenonMainZone = DenonMainZone,
-        aux_zone: Zone = DenonAuxZone
+        heart_beat: Optional[float] = denon_const.DEFAULT_HEART_BEAT,
+        http_api=None,
+        telnet: bool = True,
+        timeout: float = denon_const.DEFAULT_TIMEOUT,
+        zone_aux_class: Zone = DenonAuxZone,
+        zone_main_class: DenonMainZone = DenonMainZone,
     ):
         super().__init__(
             host,
-            telnet=telnet,
-            http=http,
-            http_api=http_api,
-            upnp=upnp,
-            timeout=timeout,
-            heart_beat=heart_beat,
             dispatcher=dispatcher,
-            main_zone=main_zone,
-            aux_zone=aux_zone,
+            heart_beat=heart_beat,
+            http_api=http_api,
+            telnet=telnet,
+            timeout=timeout,
+            zone_aux_class=zone_aux_class,
+            zone_main_class=zone_main_class,
         )
         self._connection = DenonTelnetConnection(
             self,
