@@ -1,4 +1,6 @@
 """Define Denon/Marantz A/V Receiver Zones."""
+from typing import Coroutine
+
 from pyavreceiver.denon import const as denon_const
 from pyavreceiver.zone import MainZone, Zone
 
@@ -9,7 +11,7 @@ class DenonAuxZone(Zone):
     @property
     def source_list(self):
         """Return a list of available input sources."""
-        sources = [k for k, v in self.avr.sources.keys() if v is not None]
+        sources = [k for k, v in self.avr.sources.items() if v is not None]
         sources.append(denon_const.SOURCE_FOLLOW)
         return sources
 
@@ -22,11 +24,6 @@ class DenonMainZone(MainZone):
         """The state of Audyssey dynamic EQ."""
         return self.get(denon_const.ATTR_DYNAMIC_EQ)
 
-    def set_audyssey_dynamic_eq(self, val: bool) -> bool:
+    def set_audyssey_dynamic_eq(self, val: bool) -> Coroutine:
         """Request the receiver set Audyssey dynamic EQ to val."""
-        return self.set(denon_const.ATTR_DYNAMIC_EQ, val)
-
-    @property
-    def source_list(self):
-        """Return a list of available input sources."""
-        return [k for k, v in self.avr.sources.keys() if v is not None]
+        return self.set(denon_const.ATTR_DYNAMIC_EQ, val, 2)
